@@ -36,13 +36,14 @@ use Clone 'clone';
 
 use App::Aphra::File;
 
-our $VERSION = '0.0.3';
+our $VERSION = '0.0.4';
 
 has commands => (
   isa => 'HashRef',
   is => 'ro',
   default => sub { {
     build => \&build,
+    serve => \&serve,
   } },
 );
 
@@ -60,8 +61,8 @@ sub _build_config_defaults {
     wrapper    => 'page',
     target     => 'docs',
     extensions => {
-      template => 'tt',
-      markdown => 'md',
+      tt => 'template',
+      md => 'markdown',
     },
     output     => 'html',
   };
@@ -181,6 +182,18 @@ sub _make_do_this {
   };
 }
 
+sub serve {
+  my $self = shift;
+
+  require App::HTTPThis;
+  if ($@) {
+    croak "App::HTTPThis must be installed for 'serve' command";
+  }
+
+  local @ARGV = $self->config->{target};
+  App::HTTPThis->new->run;
+}
+
 sub version {
   my $me = basename $0;
   say "\n$me version: $VERSION\n";
